import pytest

from gso.products.product_blocks.site import LatitudeCoordinate, LongitudeCoordinate


@pytest.mark.parametrize(
    ("input_value", "is_valid"),
    [
        ("40.7128", True),
        ("-74.0060", True),
        ("90", True),
        ("-90", True),
        ("0", True),
        ("45.6", True),
        ("91", False),
        ("-91", False),
        ("180", False),
        ("-180", False),
        ("abc", False),
        ("90.1", False),
    ],
)
def test_latitude(input_value, is_valid):
    if is_valid:
        assert LatitudeCoordinate.validate(input_value) == input_value
    else:
        with pytest.raises(ValueError) as excinfo:
            LatitudeCoordinate.validate(input_value)
        assert "Invalid latitude coordinate" in str(excinfo.value)


@pytest.mark.parametrize(
    ("input_value", "is_valid"),
    [
        ("40.7128", True),
        ("-74.0060", True),
        ("180", True),
        ("-180", True),
        ("0", True),
        ("90.1", True),
        ("181", False),
        ("-181", False),
        ("200", False),
        ("-200", False),
        ("abc", False),
        ("90a", False),
    ],
)
def test_longitude(input_value, is_valid):
    if is_valid:
        assert LongitudeCoordinate.validate(input_value) == input_value
    else:
        with pytest.raises(ValueError) as excinfo:
            LongitudeCoordinate.validate(input_value)
        assert "Invalid longitude coordinate" in str(excinfo.value)
